function obj = MFSMP(testcase)
tStart = tic; %The time used is logged

%The fleets are derived based on the results from FICO Xpress
[largestfleet,NumFleets,Ves] = getFleets(testcase); 
obj = inf; %Minimization
Attribute = xlsread('ReadAttributes.xlsx'); %Fleet attributes are read
FinalResults = zeros(NumFleets,7); %Used as an overview of all factors 
for i = 1:size(Attribute,2)/6 %size(Attributes,2)/6 = number of fleets(39)
    tic
    fleetsim_start = i %Tells us what fleet is being evaluated 
%Removed NaaN as presented from getFleets.m    
if find(isnan(Attribute(:,6*i-5:6*i)),1) > 0
    A = Attribute(:,6*i-5:6*i);
    B = find(isnan(A),1)-1;
    Attributes = A(1:B,:)
else
    Attributes = Attribute(:,6*i-5:6*i)
end

%Reads information on the fish farms from local Excel file.
if testcase == 1
    FishFarms = xlsread('FishFarms.xlsx');
elseif testcase == 2
    FishFarms = xlsread('FishFarms2.xlsx');
elseif testcase == 3
    FishFarms = xlsread('FishFarms3.xlsx');
else
    error('Invalid case number')
end

%Makes values obtainable for the simulation model
assignin('base','FishFarms',FishFarms)
NumFarms = size(FishFarms,1);
assignin('base','NumFarms',NumFarms)
NumRoutes = NumFarms * 4;
assignin('base','NumRoutes',NumRoutes)

%The missions are derived based on the results from FICO Xpress
MissionLists = getMissions(NumRoutes,largestfleet,NumFarms,testcase,Ves);
if find(isnan(MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i)),1) > 0
    C = MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i);
    D = find(isnan(C),1)-1;
    MissionList = C(1:D,:)
else
    MissionList = MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i)
end 

assignin('base','MissionList',MissionList)
NumShips = size(Attributes,1);
assignin('base','Attributes',Attributes)
assignin('base','NumShips',NumShips)

%Initiates simulation model in Simulink SimEvents
if testcase == 1
    [z] = sim('MFSMP_Sim');
elseif testcase == 2
    [z] = sim('MFSMP_Sim2');
elseif testcase == 3
    [z] = sim('MFSMP_Sim3');
else
    error('Invalid case number')
end

%Takes the last value of the logged data as the final backlog value
backlog = z.yout{1}.Values.Data(end);
performance = z.simout.Data(:,:,end)
Performances(i) = performance(1,1);

%Calculates the objective function, based on the backlog and costs
solution = backlog;
     %If the derived solution is better than the previous best: update
     if solution < obj
        obj = solution;
        writematrix(performance,'BestPerformance.xlsx');
        writematrix(Attributes,'FinalSolution.xlsx');
     end
fleetsim_fin = i
T(i) = toc
Results(i,1) = performance(1,1); %Total performance
Results(i,2) = performance(2,1); %Investment cost
Results(i,3) = performance(2,2); %Running cost
Results(i,4) = performance(1,3); %Emission 
Results(i,5) = performance(1,4); %Welfare value
Results(i,6) = performance(1,5); %Mission penalty cost
Results(i,7) = performance(2,5); %Overtime cost
end
%Writes the results seen above for the optimal solution to Excel file
writematrix(Results,'Results.xlsx')
AllPerformances = Performances
BestRun = find(AllPerformances==obj) %Presents the best run
Attribute = xlsread('ReadAttributes.xlsx');
if find(isnan(Attribute(:,6*BestRun-5:6*BestRun)),1) > 0
    A = Attribute(:,6*BestRun-5:6*BestRun);
    B = find(isnan(A),1)-1;
    Attributes = A(1:B,:);
else
    Attributes = Attribute(:,6*BestRun-5:6*BestRun);
end
%Writes the optimal solution to an Excel file
writematrix(Attributes,'Solution.xlsx');

%Derive if any of the fleets evaluated were identical - may indicate error
Identical = 0;
for i = 1:length(AllPerformances)-1
    for j = i+1:length(AllPerformances)
        if AllPerformances(i) == AllPerformances(j)
            fprintf('Identical runs: %.4f and %.4f', i, j)
            Identical = 1;
        end
    end
end
if Identical == 0
   fprintf('No identical runs \n')
end

%end %Should be active if Epoch-Era Analysis is not to be performed


%EPOCH-ERA ANALYSIS STARTS HERE:

%The derived performance values are based on 1.5 years of simulations. 
%We will now derive the value for the fleets' expected lifetime (25 years)

AnnualPerformance = AllPerformances/1.5
f = 0.03;           %Inflation
i = 0.10;           %Interest
p = (1+i)/(1+f)-1   %Market interest adjusted for inflation
n = 25;             %Estimated life time
r = ((1+p)^n-1)/(p*(1+p)^n) %Present value factor
LifePerformance = AnnualPerformance * r
if testcase == 1
    writematrix(LifePerformance,'PerformanceReport.xlsx')
elseif testcase == 2
    writematrix(LifePerformance,'PerformanceReport2.xlsx')
else
    writematrix(LifePerformance,'PerformanceReport3.xlsx')
end

%Initiates Epoch-Era Analysis for Era 1
EraPerformance1 = MFSMP_E1(testcase,AllPerformances,p)
if testcase == 1
    writematrix(EraPerformance1,'PerformanceReport.xlsx','Range','A2')
elseif testcase == 2
    writematrix(EraPerformance1,'PerformanceReport2.xlsx','Range','A2')
else
    writematrix(EraPerformance1,'PerformanceReport3.xlsx','Range','A2')
end

%Initiates Epoch-Era Analysis for Era 2
EraPerformance2 = MFSMP_E2(testcase,AllPerformances,p)
if testcase == 1
    writematrix(EraPerformance2,'PerformanceReport.xlsx','Range','A3')
elseif testcase == 2
    writematrix(EraPerformance2,'PerformanceReport2.xlsx','Range','A3')
else
    writematrix(EraPerformance2,'PerformanceReport3.xlsx','Range','A3')
end

%Initiates Epoch-Era Analysis for Era 3
EraPerformance3 = MFSMP_E3(testcase,AllPerformances,p)  
if testcase == 1
    writematrix(EraPerformance3,'PerformanceReport.xlsx','Range','A4')
elseif testcase == 2
    writematrix(EraPerformance3,'PerformanceReport2.xlsx','Range','A4')
else
    writematrix(EraPerformance3,'PerformanceReport3.xlsx','Range','A4')
end


delete ReadAttributes.xlsx %Deletes Excel-file to not create complications
tEnd = toc(tStart); %Logs and presents time used
fprintf('%d hours, %d minutes and %f seconds\n', floor(tEnd/3600), floor(rem(tEnd,3600)/60), round(rem(tEnd,60)));

end