function [largestfleet,NumFleets,Ves] = getFleets(testcase)
if testcase == 1 %Reads the vessels in each fleet from Xpress results
    f = xlsread('AllVessels.xlsx');
elseif testcase == 2
    f = xlsread('AllVessels2.xlsx');
elseif testcase == 3
    f = xlsread('AllVessels3.xlsx');
else
    error('Invalid case number')
end

%Removes all entries indicating that a vessel has NOT been chosen
i = 1;
while i <= length(f)
    if f(i,2) == 0
        f(i,:) = [];
    else
        i = i+1;
    end
end

%Derive the number of fleets and how long the entry for each fleet is
NumFleets = 1;
B = [];
for j = 2:length(f)
    if f(j,1) < f(j-1,1)
        B(NumFleets) = j;
        NumFleets = NumFleets + 1;
    end
end
B(NumFleets) = length(f)+1;

%Derives the number of different vessel types in the fleet
VesInFleet = [];
VesInFleet(1) = B(1)-1;
for i = 2:NumFleets
    VesInFleet(i) = B(i)-B(i-1);
end

%Rearrange the fleet list
g = zeros(max(VesInFleet),2*NumFleets);
g(1:B(1)-1,1:2) = f(1:B(1)-1,:);

for i = 2:length(B)
    g(1:B(i)-B(i-1),2*i-1:2*i) = f(B(i-1):B(i)-1,:);
end
for i = 1:NumFleets
    Ves(:,2*i-1:2*i) = sortrows(g(:,2*i-1:2*i),'descend');
end

%Changes the vessel number used in Xpress to actual vessel attributes
if testcase == 3 %Less vessels available due to software restriction
    rawData = xlsread('TheVessels3.xlsx'); %200 different vessels
else
    rawData = xlsread('TheVessels.xlsx');  %400 different vessels
end

%Derive the largest number of vessels in a fleet to create vessel list
largestfleet = sum(Ves(:,2));
for i = 2:NumFleets
    if sum(Ves(:,2*i)) > largestfleet
        largestfleet = round(sum(Ves(:,2*i)));
    end
end

%Creates list of vessels in each fleet as a large matrix
h = zeros(largestfleet,6*NumFleets);
i = 1;
for a = 1:NumFleets
    for j = 1:6 %6 different attributes.
        h(i:(i+Ves(i,2*a)-1),j+6*(a-1)) = round(rawData(j+1,Ves(i,2*a-1))); 
    end
end
for a = 1:NumFleets
    for i = 2:VesInFleet(a)
        for j = 1:6
            h(1+sum(Ves(1:(i-1),2*a)):1+sum(Ves(1:i,2*a))-1,j+6*(a-1)) = round(rawData(j+1,Ves(i,2*a-1)));
        end 
    end
end
for i = 1:size(h,1)
    for j = 1:size(h,2)/6
        if sum(h(i,6*j-5:6*j)) == 0
            h(i,6*j-5:6*j) = NaN;
        end
    end
end

%Writes the attributes of each vessel in each fleet to Excel file. 
writematrix(h,'ReadAttributes.xlsx')

end