function obj = WellboatOpti(testcase)
tStart = tic;%The time used is logged

%The fleets are derived based on the results from FICO Xpress
[largestfleet,NumFleets,Ves] = getFleets(testcase);
obj = inf; %Minimization
Attribute = xlsread('ReadAttributes.xlsx'); %Fleet attributes are read
Results = zeros(NumFleets,7); %Used as an overview of all factors 
for i = 1:size(Attribute,2)/5 %size(Attributes,2)/5 = number of fleets(39)
    tic
    fleetsim_start = i %Tells us what fleet is being evaluated 
%Removed NaaN as presented from getFleets.m  
if find(isnan(Attribute(:,5*i-4:5*i)),1) > 0
    A = Attribute(:,5*i-4:5*i);
    B = find(isnan(A),1)-1;
    Attributes = A(1:B,:)
else
    Attributes = Attribute(:,5*i-4:5*i)
end

%Reads information on the fish farms from local Excel file.
if testcase == 1
    FishFarms = xlsread('FishFarms.xlsx');
elseif testcase == 2
    FishFarms = xlsread('FishFarms2.xlsx');
elseif testcase == 3
    FishFarms = xlsread('FishFarms3.xlsx');
else
    error('Invalid case number')
end

%Makes values obtainable for the simulation model
assignin('base','FishFarms',FishFarms)
NumFarms = size(FishFarms,1);
assignin('base','NumFarms',NumFarms)
NumRoutes = NumFarms * 3;
assignin('base','NumRoutes',NumRoutes)

%The missions are derived based on the results from FICO Xpress
MissionLists = getMissions(NumRoutes,largestfleet,testcase,Ves);
if find(isnan(MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i)),1) > 0
    C = MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i);
    D = find(isnan(C),1)-1;
    MissionList = C(1:D,:)
else
    MissionList = MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i)
end 

assignin('base','MissionList',MissionList)

%VesselLink = ones(size(Attributes,1),size(FishFarms,1));
NumShips = size(Attributes,1);
assignin('base','Attributes',Attributes)
assignin('base','NumShips',NumShips)

%Initiates simulation model in Simulink SimEvents
if testcase == 1
    [z] = sim('WellboatSim');
elseif testcase == 2
    [z] = sim('WellboatSim2');
elseif testcase == 3
    [z] = sim('WellboatSim3');
else
    error('Invalid case number')
end

%Takes the last value of the logged data as the final backlog value
backlog = z.yout{1}.Values.Data(end);
performance = z.simout.Data(:,:,end)
Performances(i) = performance(1,1);
solution = backlog;
     if solution < obj
        obj = solution;
     end
fleetsim_fin = i
T(i) = toc
Results(i,1) = performance(1,1); %Total performance
Results(i,2) = performance(2,1); %Investment cost
Results(i,3) = performance(2,2); %Running cost
Results(i,4) = performance(2,3); %Emission 
Results(i,5) = performance(2,4); %Unweighted welfare value
Results(i,6) = performance(1,5); %Mission penalty cost
Results(i,7) = performance(2,5); %Overtime cost
end
%Writes the results seen above for the optimal solution to Excel file
writematrix(Results,'Results.xlsx')
AllPerformances = Performances
BestRun = find(AllPerformances==obj)
Attribute = xlsread('ReadAttributes.xlsx');
if find(isnan(Attribute(:,5*BestRun-4:5*BestRun)),1) > 0
    A = Attribute(:,5*BestRun-4:5*BestRun);
    B = find(isnan(A),1)-1;
    Attributes = A(1:B,:);
else
    Attributes = Attribute(:,5*BestRun-4:5*BestRun);
end
%Writes the optimal solution to an Excel file
writematrix(Attributes,'Solution.xlsx');

%Derive if any of the fleets evaluated were identical - may indicate error
Identical = 0;
for i = 1:length(AllPerformances)-1
    for j = i+1:length(AllPerformances)
        if AllPerformances(i) == AllPerformances(j)
            fprintf('Identical runs: %.4f and %.4f', i, j)
            Identical = 1;
        end
    end
end
if Identical == 0
   fprintf('No identical runs \n')
end

tEnd = toc(tStart); %Logs and presents computational time
fprintf('%d hours, %d minutes and %f seconds\n', floor(tEnd/3600), floor(rem(tEnd,3600)/60), round(rem(tEnd,60)));
delete ReadAttributes.xlsx %Deletes Excel-file to not create complications
end