function obj = WellboatOptiFuel(testcase) %Used for Cost-Emission relations
tStart = tic;
[largestfleet,NumFleets,Ves] = getFleets(testcase);
obj = inf;
Attribute = xlsread('ReadAttributes.xlsx');
for a = 1:14 %14 different fuel combinations are to be tested
%This means that 14x39 = 546 fleets are to be evaluated in the sim. model
for i = 1:size(Attribute,2)/5
    tic
    fleetsim_start = i
if find(isnan(Attribute(:,5*i-4:5*i)),1) > 0
    A = Attribute(:,5*i-4:5*i);
    B = find(isnan(A),1)-1;
    Attributes = A(1:B,:)
else
    Attributes = Attribute(:,5*i-4:5*i)
end

if testcase == 1
    FishFarms = xlsread('FishFarms.xlsx');
elseif testcase == 2
    FishFarms = xlsread('FishFarms2.xlsx');
elseif testcase == 3
    FishFarms = xlsread('FishFarms3.xlsx');
else
    error('Invalid case number')
end

assignin('base','FishFarms',FishFarms)
NumFarms = size(FishFarms,1);
assignin('base','NumFarms',NumFarms)
NumRoutes = NumFarms * 3;
assignin('base','NumRoutes',NumRoutes)
Fuel = a;
assignin('base','Fuel',Fuel)
Fuels = a+i; %Used for random generations in the simulation model.
assignin('base','Fuels',Fuels)

MissionLists = getMissions(NumRoutes,largestfleet,testcase,Ves);
if find(isnan(MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i)),1) > 0
    C = MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i);
    D = find(isnan(C),1)-1;
    MissionList = C(1:D,:)
else
    MissionList = MissionLists(:,NumRoutes*(i-1)+1:NumRoutes*i)
end 

assignin('base','MissionList',MissionList)

NumShips = size(Attributes,1);
assignin('base','Attributes',Attributes)
assignin('base','NumShips',NumShips)

if testcase == 1
    [z] = sim('WellboatSim_emissions');
elseif testcase == 2
    [z] = sim('WellboatSim_emissions2');
elseif testcase == 3
    [z] = sim('WellboatSim_emissions3');
else
    error('Invalid case number')
end


%Takes the last value of the logged data as the final backlog value
backlog = z.yout{1}.Values.Data(end);
performance = z.simout.Data(:,:,end)
Performances(size(Attribute,2)/5*(a-1)+i) = performance(1,1);
Emissions(size(Attribute,2)/5*(a-1)+i) = performance(2,3);

solution = backlog;

     if solution < obj
        obj = solution;
     end
fleetsim_fin = i
T(NumFleets*(a-1)+i) = toc
end
end
AllPerformances = Performances
BestRun = find(AllPerformances==obj)

Identical = 0;
for i = 1:length(AllPerformances)-1
    for j = i+1:length(AllPerformances)
        if AllPerformances(i) == AllPerformances(j)
            fprintf('Identical runs: %.4f and %.4f', i, j)
            Identical = 1;
        end
    end
end
if Identical == 0
   fprintf('No identical runs \n')
end

%Design the Cost-Emission plot and the Pareto front
MinEm = [];
MinCo = [];
Values = [];
MinCo(1) = min(Performances);
MinEm(1) = Emissions(find(Performances == MinCo(1)));

for i = 1:10000000
    Interval = [min(Performances)+(i-1)/10000000*(max(Performances)-min(Performances)),min(Performances)+i/10000000*(max(Performances)-min(Performances))];
    Positions = find(Performances <= Interval(2) & Performances >= Interval(1));
    for j = 1:length(Positions)
        Values(j) = Performances(Positions(j));
    end
    if isempty(Values) == 0
        if Emissions(find(Performances == min(Values))) < MinEm(end)
            MinCo(length(MinEm)+1) = min(Values);
            MinEm(length(MinCo)) = Emissions(find(Performances == MinCo(end)));
        end
        Values = [];
    end
    
end
    
plot(Performances,Emissions,'o')
hold on
plot(MinCo, MinEm,'LineWidth',2)
yline(Emissions(find(Performances == MinCo(1))),'r','Cost-effective solution');
yline(Emissions(find(Performances == MinCo(1)))*0.95,'r','5% decrease');
yline(Emissions(find(Performances == MinCo(1)))*0.90,'r','10% decrease');
yline(Emissions(find(Performances == MinCo(1)))*0.80,'r','20% decrease');
yline(Emissions(find(Performances == MinCo(1)))*0.50,'r','50% decrease');
yline(0,'r','100% decrease');
hold off
title('Cost-Emission Relations')
xlabel('Cost [USD]') 
ylabel('Emissions [kg CO2]')

tEnd = toc(tStart);
fprintf('%d hours, %d minutes and %f seconds\n', floor(tEnd/3600), floor(rem(tEnd,3600)/60), round(rem(tEnd,60)));
delete ReadAttributes.xlsx
end