function MissionList = getMissions(NumRoutes,largestfleet,testcase,Ves)
%Derive the routing of the vessels from Xpress
if testcase == 1
    ReadMissionList = xlsread('MissionList.xlsx');
    OptiRoutes = 20; %Number of routes used for the case in Xpress
elseif testcase == 2
    ReadMissionList = xlsread('MissionList2.xlsx');
    OptiRoutes = 40;
elseif testcase == 3
    ReadMissionList = xlsread('MissionList3.xlsx');
    OptiRoutes = 80;
else
    error('Invalid case number')
end

NumFleets = size(Ves,2)/2;
NumPossibleVessels = size(ReadMissionList,1)/NumFleets/OptiRoutes;
VesxRou = OptiRoutes*NumPossibleVessels;

%Tries to quickly decrease the size of the large Excel-file from Xpress
NotRemoved = 0;
a = 0;
for i = 1:NumFleets
    Vessels = Ves(:,2*i-1);
    if i == 1
        NotRemoved = 0;
    else
        NotRemoved = NotRemoved + (NumPossibleVessels - a)*OptiRoutes;
    end
    a = 0;
        for j = 1:NumPossibleVessels
            if isempty(find(Vessels == j))
                ReadMissionList(OptiRoutes*(j-a-1)+1+NotRemoved:OptiRoutes*(j-a)+NotRemoved,:) = [];
                a = a + 1;
            end
        end
end


%As above, we are now removing entries that denotes a route not being used
i = 1;
    while i <= length(ReadMissionList)
        if ReadMissionList(i,3) == 0
            ReadMissionList(i,:) = [];
        else
            i = i+1;
        end
    end

NumFleets = 1;
B = [];
for j = 2:length(ReadMissionList)
    if ReadMissionList(j,1) < ReadMissionList(j-1,1)
        B(NumFleets) = j;
        NumFleets = NumFleets + 1;
    end
end     
B(NumFleets) = length(ReadMissionList)+1;

largestgap = B(1) - 1;
for i = 2:length(B)
    if B(i) - B(i-1) > largestgap
        largestgap = B(i) - B(i-1);
    end
end

%Sort the vessels and the missions
g = zeros(largestgap,3*NumFleets);
g(1:B(1)-1,1:3) = ReadMissionList(1:B(1)-1,:);

for i = 2:NumFleets
    g(1:B(i)-B(i-1),3*i-2:3*i) = ReadMissionList(B(i-1):B(i)-1,:);
end

for i = 1:NumFleets
    SortedMissionList(:,3*i-2:3*i) = sortrows(g(:,3*i-2:3*i),'descend');
end


%Create the mission list as a large matrix
MissionList = zeros(largestfleet,NumRoutes*NumFleets);
for j = 1:NumFleets
    Ves = 1;
    Rou = SortedMissionList(1,3*j-1);
    Ops = SortedMissionList(1,3*j);
    if Ops <= 6 %Max 6 missions per week for each vessel
    MissionList(Ves,Rou+NumRoutes*(j-1)) = Ops;
    else
        MissionList(Ves,Rou+NumRoutes*(j-1)) = 6;
        MissionList(Ves+1,Rou+NumRoutes*(j-1)) = Ops-6;
    end
    for i = 2:size(SortedMissionList,1)
        if SortedMissionList(i,3*j-2) ~= SortedMissionList(i-1,3*j-2)
            if SortedMissionList(i,3*j-2) == 0
                break
            else
                Ves = Ves + 1;
            end
        end
        Rou = SortedMissionList(i,3*j-1);
        Ops = SortedMissionList(i,3*j);
        if sum(MissionList(Ves,NumRoutes*(j-1)+1:NumRoutes*j)) <= 6-Ops 
            MissionList(Ves,Rou+NumRoutes*(j-1)) = MissionList(Ves,Rou+NumRoutes*(j-1)) + Ops;
        else
            MissionList(Ves,Rou+NumRoutes*(j-1)) = 6 - sum(MissionList(Ves,NumRoutes*(j-1)+1:NumRoutes*j));
            if Ops - MissionList(Ves,Rou+NumRoutes*(j-1)) <= 6
                MissionList(Ves+1,Rou+NumRoutes*(j-1)) = Ops - MissionList(Ves,Rou+NumRoutes*(j-1));
                Ves = Ves + 1;
            else
                MissionList(Ves+1,Rou+NumRoutes*(j-1)) = 6;
                MissionList(Ves+2,Rou+NumRoutes*(j-1)) = Ops - MissionList(Ves,Rou+NumRoutes*(j-1))-6;
                Ves = Ves + 2;
            end
        end
    end
end

%Makes sure that all missions are integers
for i = 1:size(MissionList,1)
    for j = 1:size(MissionList,2)
        MissionList(i,j) = ceil(MissionList(i,j));
    end
end

%Changes entire rows of zeros into NaaN indicating that there is no vessel
for i = 1:NumFleets
    for j = 1:size(MissionList,1)
        if sum(MissionList(j,NumRoutes*(i-1)+1:NumRoutes*i)) == 0
            MissionList(j,NumRoutes*(i-1)+1:NumRoutes*i) = NaN;
        end
    end
end
    